@@ -7,8 +7,10 @@ class Config(object):
   Add all config attributes in the parent class with a default.
   Then override as needed in the environment specific configs
   """
-  AWS_ACCESS_KEY_ID = os.environ.get("AWS_ACCESS_KEY_ID", os.environ.get("ACCESS_KEY_ID"))
-  AWS_SECRET_ACCESS_KEY = os.environ.get("AWS_SECRET_ACCESS_KEY", os.environ.get("SECRET_ACCESS_KEY"))
+  AWS_ACCESS_KEY_ID = os.environ.get("AWS_ACCESS_KEY_ID")
+  AWS_SECRET_ACCESS_KEY = os.environ.get("AWS_SECRET_ACCESS_KEY")
+  ACCESS_KEY_ID=os.environ.get("ACCESS_KEY_ID")
+  SECRET_ACCESS_KEY=os.environ.get("SECRET_ACCESS_KEY")
   LOG_APP_NAME= os.getenv('LOG_APP_NAME')
   LOG_LEVEL = os.environ.get('LOG_LEVEL', 'INFO')
   GOOGLE_API_KEY = os.getenv('GOOGLE_API_KEY')
